==> theia-0.1.1-py3-none-any.whl: theia/definitions.py <==
import pkg_resources
from typing import Literal

THEIA_VERSION = {
    "theia_version": pkg_resources.get_distribution("theia").version,
    "created_by": "theia",
}

AWS_REGION = Literal[
    "us-east-1",
    "us-east-2",
    "us-west-1",
    "us-west-2",
    "af-south-1",
    "ap-east-1",
    "ap-south-2",
    "ap-southeast-3",
    "ap-southeast-4",
    "ap-south-1",
    "ap-northeast-3",
    "ap-northeast-2",
    "ap-southeast-1",
    "ap-southeast-2",
    "ap-northeast-1",
    "ca-central-1",
    "eu-central-1",
    "eu-west-1",
    "eu-west-2",
    "eu-south-1",
    "eu-west-3",
    "eu-south-2",
    "eu-north-1",
    "eu-central-2",
    "me-south-1",
    "me-central-1",
    "sa-east-1",
    "us-gov-east-1",
    "us-gov-west-1",
]

TRAFFIC_MAP = {
    "All": {"from": 0, "to": 0, "protocol": "-1"},
    "All TCP": {"from": 0, "to": 65535, "protocol": "tcp"},
    "All UDP": {"from": 0, "to": 65535, "protocol": "udp"},
    "SSH": {"from": 22, "to": 22, "protocol": "ssh"},
    "SMTP": {"from": 25, "to": 25, "protocol": "tcp"},
    "DNS (UDP)": {"from": 53, "to": 53, "protocol": "udp"},
    "DNS (TCP)": {"from": 53, "to": 53, "protocol": "tcp"},
    "HTTP": {"from": 80, "to": 80, "protocol": "tcp"},
    "HTTPS": {"from": 443, "to": 443, "protocol": "tcp"},
    "RDP": {"from": 3389, "to": 3389, "protocol": "tcp"},
}

LAMBDA_RUNTIMES = Literal[
    "dotnetcore3.1",
    "dotnet5.0",
    "dotnet6",
    "go1.x",
    "java8",
    "java8.al2",
    "java11",
    "ruby2.7",
    "nodejs12.x",
    "nodejs14.x",
    "nodejs16.x",
    "nodejs18.x",
    "python3.7",
    "python3.8",
    "python3.9",
]

AMI_TYPES = Literal[
    "AL2_x86_64",
    "AL2_x86_64_GPU",
    "AL2_ARM_64",
    "CUSTOM",
    "BOTTLEROCKET_ARM_64",
    "BOTTLEROCKET_x86_64",
    "BOTTLEROCKET_ARM_64_NVIDIA",
    "BOTTLEROCKET_x86_64_NVIDIA",
    "WINDOWS_CORE_2019_x86_64",
    "WINDOWS_FULL_2019_x86_64",
    "WINDOWS_CORE_2022_x86_64",
    "WINDOWS_FULL_2022_x86_64",
]

==> theia-0.1.2-py3-none-any.whl: theia/definitions.py <==
import pkg_resources
from typing import Literal

THEIA_VERSION = {
    "theia_version": pkg_resources.get_distribution("theia").version,
}

AWS_REGION = Literal[
    "us-east-1",
    "us-east-2",
    "us-west-1",
    "us-west-2",
    "af-south-1",
    "ap-east-1",
    "ap-south-2",
    "ap-southeast-3",
    "ap-southeast-4",
    "ap-south-1",
    "ap-northeast-3",
    "ap-northeast-2",
    "ap-southeast-1",
    "ap-southeast-2",
    "ap-northeast-1",
    "ca-central-1",
    "eu-central-1",
    "eu-west-1",
    "eu-west-2",
    "eu-south-1",
    "eu-west-3",
    "eu-south-2",
    "eu-north-1",
    "eu-central-2",
    "me-south-1",
    "me-central-1",
    "sa-east-1",
    "us-gov-east-1",
    "us-gov-west-1",
]

TRAFFIC_MAP = {
    "All": {"from": 0, "to": 0, "protocol": "-1"},
    "All TCP": {"from": 0, "to": 65535, "protocol": "tcp"},
    "All UDP": {"from": 0, "to": 65535, "protocol": "udp"},
    "SSH": {"from": 22, "to": 22, "protocol": "tcp"},
    "SMTP": {"from": 25, "to": 25, "protocol": "tcp"},
    "DNS (UDP)": {"from": 53, "to": 53, "protocol": "udp"},
    "DNS (TCP)": {"from": 53, "to": 53, "protocol": "tcp"},
    "HTTP": {"from": 80, "to": 80, "protocol": "tcp"},
    "HTTPS": {"from": 443, "to": 443, "protocol": "tcp"},
    "RDP": {"from": 3389, "to": 3389, "protocol": "tcp"},
}

LAMBDA_RUNTIMES = Literal[
    "dotnetcore3.1",
    "dotnet5.0",
    "dotnet6",
    "go1.x",
    "java8",
    "java8.al2",
    "java11",
    "ruby2.7",
    "nodejs12.x",
    "nodejs14.x",
    "nodejs16.x",
    "nodejs18.x",
    "python3.7",
    "python3.8",
    "python3.9",
]

AMI_TYPES = Literal[
    "AL2_x86_64",
    "AL2_x86_64_GPU",
    "AL2_ARM_64",
    "CUSTOM",
    "BOTTLEROCKET_ARM_64",
    "BOTTLEROCKET_x86_64",
    "BOTTLEROCKET_ARM_64_NVIDIA",
    "BOTTLEROCKET_x86_64_NVIDIA",
    "WINDOWS_CORE_2019_x86_64",
    "WINDOWS_FULL_2019_x86_64",
    "WINDOWS_CORE_2022_x86_64",
    "WINDOWS_FULL_2022_x86_64",
]
